@@ -5,7 +5,7 @@
 
 use strict;
 use warnings;
-use Test::More tests => 1;
+use Test::More tests => 2;
 use Test::Differences::Color;
 
 my $data1 = {
@@ -28,4 +28,15 @@ my $data2 = {
     },
 };
 
-eq_or_diff($data1, $data2);
+my $data3 = {
+    x => [1,2,3,4,5],
+    a => 1,
+    b => [2,3],
+    c => {
+        x => 101,
+    },
+};
+
+#eq_or_diff($data1, $data2);
+eq_or_diff($data3, $data2);
+eq_or_diff($data2, $data3);
